# 机器人QQ号
bot_qq = 3035332291
# 开发者QQ号
super_qq = 2782383376


def monitor_rongyu(honor_type, user_id):
    rely = ""
    # 龙王
    if honor_type == "talkative":
        if user_id == bot_qq:
            rely = f"你们又不行了，本喵喜提龙王~"
        elif user_id == super_qq:
            rely = f"[CQ:at,qq={user_id}]恭喜主人荣获龙王标识~"
        else:
            rely = f"恭喜[CQ:at,qq={user_id}]荣获龙王标识~"
    # 群聊之火
    elif honor_type == "performer":
        if user_id == bot_qq:
            pass
        elif user_id == super_qq:
            rely = f"[CQ:at,qq={user_id}]恭喜主人荣获群聊之火标识~"
        else:
            rely = f"恭喜[CQ:at,qq={user_id}]荣获群聊之火标识~"
    # 快乐源泉
    elif honor_type == "emotion":
        if user_id == bot_qq:
            pass
        elif user_id == super_qq:
            rely = f"[CQ:at,qq={user_id}]恭喜主人荣获快乐源泉标识~"
        else:
            rely = f"恭喜[CQ:at,qq={user_id}]荣获快乐源泉标识~"
    return rely



from nonebot.rule import Rule
from nonebot.typing import T_State
from nonebot.plugin import on_notice

from nonebot.adapters.onebot.v11 import (
    Bot, Event, Message,
    PokeNotifyEvent,
    HonorNotifyEvent,
    GroupUploadNoticeEvent,
    GroupDecreaseNoticeEvent,
    GroupIncreaseNoticeEvent,
    GroupAdminNoticeEvent,
    LuckyKingNotifyEvent
)

from .chuoyichuo import chuo_send_msg
from .rongyu import monitor_rongyu
from .admin import *


# 获取戳一戳状态
async def _is_poke(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, PokeNotifyEvent) and event.is_tome()


# 获取群荣誉变更
async def _is_rongyu(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, HonorNotifyEvent)


# 获取文件上传
async def _is_checker(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, GroupUploadNoticeEvent)


# 群成员减少
async def _is_del_user(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, GroupDecreaseNoticeEvent)


# 群成员增加
async def _is_add_user(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, GroupIncreaseNoticeEvent)


# 管理员变动
async def _is_admin_change(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, GroupAdminNoticeEvent)


# 红包运气王
async def _is_red_packet(bot: Bot, event: Event, state: T_State) -> bool:
    return isinstance(event, LuckyKingNotifyEvent)


# 戳一戳
chuo = on_notice(Rule(_is_poke), priority=50, block=True)
# 群荣誉
rongyu = on_notice(Rule(_is_rongyu), priority=50, block=True)
# 群文件
files = on_notice(Rule(_is_checker), priority=50, block=True)
# 群员减少
del_user = on_notice(Rule(_is_del_user), priority=50, block=True)
# 群员增加
add_user = on_notice(Rule(_is_add_user), priority=50, block=True)
# 群管理
admin = on_notice(Rule(_is_admin_change), priority=50, block=True)
# 红包
red_packet = on_notice(Rule(_is_red_packet), priority=50, block=True)


@chuo.handle()
async def send_chuo(bot: Bot, event: Event, state: T_State):
    rely_msg = chuo_send_msg()
    await chuo.finish(message=Message(rely_msg))


@rongyu.handle()
async def send_rongyu(bot: Bot, event: HonorNotifyEvent, state: T_State):
    rely_msg = monitor_rongyu(event.honor_type, event.user_id)
    await send_rongyu.finish(message=Message(rely_msg))


@files.handle()
async def handle_first_receive(bot: Bot, event: GroupUploadNoticeEvent, state: T_State):
    rely = f'[CQ:at,qq={event.user_id}]\n' \
           f'[CQ:image,file=https://q4.qlogo.cn/headimg_dl?dst_uin={event.user_id}&spec=640]' \
           f'\n 上传了新文件，感谢你一直为群里做贡献[CQ:face,id=175]'
    await files.finish(message=Message(rely))


@del_user.handle()
async def user_bye(bot: Bot, event: GroupDecreaseNoticeEvent, state: T_State):
    rely_msg = del_user_bye(event.time, event.group_id, event.user_id)
    await del_user.finish(message=Message(rely_msg))


@add_user.handle()
async def user_welcome(bot: Bot, event: GroupIncreaseNoticeEvent, state: T_State):
    rely_msg = add_user_wecome(event.time, event.group_id, event.user_id)
    await add_user.finish(message=Message(rely_msg))


@admin.handle()
async def admin_chance(bot: Bot, event: GroupAdminNoticeEvent, state: T_State):
    rely_msg = admin_change(event.sub_type, event.user_id)
    await bot.finish(message=Message(rely_msg))

@red_packet.handle()
async def hongbao(bot: Bot, event: LuckyKingNotifyEvent, state: T_State):
    rely_msg = f"[CQ:at,qq={event.user_id}]\n本次红包运气王为：[CQ:at,qq={event.target_id}]"
    await red_packet.finish(message=Message(rely_msg))



from datetime import datetime

# 机器人QQ号
bot_qq = 3035332291
# 开发者QQ号
super_qq = [2782383376]
# 退群消息
del_user_msg = ""
# 入群消息
add_user_msg = ""


def admin_change(sub_type, user_id):
    admin_msg = ""
    if sub_type == "set":
        if user_id == bot_qq:
            admin_msg = f"芜湖，咱以后也是管理了~"
        else:
            admin_msg = f"恭喜[CQ:at,qq={user_id}]喜提本群管理~"
    elif sub_type == "unset":
        if user_id == bot_qq:
            admin_msg = f"呜呜，别下咱管理呀QwQ"
        else:
            admin_msg = f"[CQ:at,qq={user_id}]痛失本群管理~"
    return admin_msg


def del_user_bye(add_time, group_id, user_id):
    global groups_all, del_user_msg
    del_time = datetime.fromtimestamp(add_time)
    if user_id in super_qq:
        del_user_msg = f"<{del_time}>@{user_id}恭送主人离开~"
    else:
        del_user_msg = f"<{del_time}>QQ号为：{user_id}的小可爱退群咯，good bye呀，永别了这位朋友~" \
                       f"[CQ:image,file=https://q4.qlogo.cn/headimg_dl?dst_uin={user_id}&spec=640]"
        return del_user_msg


def add_user_wecome(add_time, group_id, user_id):
    global groups_all, add_user_msg
    add_time = datetime.fromtimestamp(add_time)
    if user_id == bot_qq:
        add_user_msg = f"唔，很荣幸受邀进入贵群~\n" \
                       f"嘤嘤嘤呜呜呜"
    elif user_id in super_qq:
        add_user_msg = f"[CQ:at,qq={user_id}]欢迎主人进群[CQ:face,id=175]"
    else:
        add_user_msg = f"欢迎[CQ:at,qq={user_id}]的加入，加入时间：{add_time}，请在群内积极发言哦~" \
                       f"[CQ:image,file=https://q4.qlogo.cn/headimg_dl?dst_uin={user_id}&spec=640]"
    return add_user_msg



import setuptools 

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="nonebot_plugin_eventmonitor",
    version="0.0.5",
    author="schwarzwald",
    description="监控群事件的插件，支持戳一戳，成员变动，群荣誉变化等提示",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Reversedeer/nonebot_plugin_eventmonitor",
    project_urls={
        "Bug Tracker": "https://github.com/Reversedeer/nonebot_plugin_eventmonitor/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.8",
    install_requires = [
        'nonebot2>=2.0.0rc1',
    ]
)


import random

bot_name = "小黑"

chuo_msg = [
    f"别戳了，{bot_name}怕疼QwQ",
    f"呜呜，再戳{bot_name}脸都要肿了",
    f"戳坏了{bot_name}，你赔得起吗？",
    f"再戳{bot_name}，我要叫我主人了",
    f"别老戳{bot_name}了，您歇会吧~",
    f"再戳{bot_name}，咬你了嗷~",
    f"想好了再戳，(*-`ω´-)✄",
    f"喂，110吗，有人老戳我",
    f"嗷呜嗷呜...恶龙咆哮┗|｀O′|┛",
    f"有事恁叫我，别天天一个劲戳戳戳！",
    f"再戳我让你变成女人，嘿嘿",
    f"不要戳我了 >_<",
    f"不要这样子啦(*/ω＼*)",
    f"不要再戳了(害怕ing)",
    f"还戳，哼(つд⊂)（生气）",
    f"再戳，小心我顺着网线找你.",
    f"咱要型气了o(>﹏<)o",
    f"嘿嘿，好舒服呀(bushi)",
    f"乖，好了好了，别戳了~",
    f"我爪巴爪巴，球球别再戳了",
    f"别再戳我了，行🐎？！",
    f"啊呜，你有什么事吗？"
]


def chuo_send_msg():
    rand_num = random.randint(0, len(chuo_msg) - 1)
    return chuo_msg[rand_num]
